************************************************************************************
** Duration and competing-risks determinants of terrorist hostage-taking incidents**
**                     European Journal of Political Economy                      **
**                          replication file (STATA v.16)                         **
************************************************************************************

use replication_data.dta, clear

*Define alternative variable
gen negosuccess = terroristnegotiationsuccess

replace negosuccess = 0 if negosuccess == 3 | negosuccess == 8 | negosuccess == 9
replace negosuccess = 1 if negosuccess == 2

gen alter = .

replace alter = 1 if shoot_out == 1
replace alter = 2 if negosuccess == 1 & shoot_out == 0
replace alter = 0 if negosuccess == 0 & shoot_out == 0

** reconstruct variables
gen lduration_hours = ln(duration_hours)
gen lransom_demand = ln(ransom_demand+1)
gen ppolity = (polity2 + 10)/20
replace ppolity = . if polity2 == .
gen ppolity2 = ppolity^2
gen lnum_hostages = ln(num_hostages+1)
gen lnum_nonter_wound = ln(num_nonter_wound+1)
gen lprisoners_demand = ln(prisoners_demand+1)
gen non_kidnapping = 1
replace non_kidnapping = 0 if kidnap == 1
gen lterroristswounded = ln(terroristswounded+1) 

keep if t == 1

***********************
*********Table 1*******
***********************
eststo clear
estpost summarize kidnap skyjacking barricade non_aerial lduration_hours lnum_hostages seq_release lransom_demand  dnum_us_victim lnum_nonter_wound ///
 polity2 democracy host_negotiation number_entities lprisoners_demand  number_nationalities deadline_past1 negotiation_change pperson

stset lduration_hours

***********************
*********figure 1*******
***********************
sts graph, by(typeofincident) // 1== kidnapping, 2==barricade, 9==skyjacking, and 10=non-aerial

***********************
*********Table 2*******
***********************

** Define variables
global x1   lnum_hostages seq_release lransom_demand  dnum_us_victim  democracy lnum_nonter_wound 
global x11  lnum_hostages seq_release lransom_demand  dnum_us_victim ppolity ppolity2  lnum_nonter_wound //
global x2 host_negotiation number_entities lprisoners_demand  number_nationalities deadline_past1 //
global x4 negotiation_change hpweapon pperson
global x5 negotiation_change pperson

** Basic model
eststo clear

eststo n1: streg $x1 kidnap,  dist(weibull) cluster(locationstart) 
eststo n2: streg $x11 $x2 skyjacking barricade non_aerial,  dist(weibull) cluster(locationstart) 
eststo n3: streg $x1 $x2 skyjacking barricade non_aerial,  dist(weibull) cluster(locationstart)
eststo n4: streg $x1 $x2 kidnap negotiation_change,  dist(weibull) cluster(locationstart)
eststo n5: streg $x1 $x2 kidnap pperson,  dist(weibull) cluster(locationstart) 

estout *, cells(b(star fmt(%9.3f)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.01) stats(alpha N, fmt(2 2 0)) label collabels("") varlabels(_cons Constant) varwidth(25) modelwidth(10)

***********************
*********Table 3*******
***********************

** only kidnap
** Define variables

global x1  num_hostages seq_release lransom_demand  dnum_us_victim democracy        
global x11 num_hostages seq_release lransom_demand  dnum_us_victim ppolity ppolity2 

global x2 number_entities lprisoners_demand  number_nationalities  


eststo clear
stset lduration_hours

eststo n1: streg $x1 $x2  if typeofincident == 1,  dist(weibull) cluster(locationstart) 
eststo n2: streg $x11 $x2 if typeofincident == 1,  dist(weibull) cluster(locationstart) 
eststo n3: streg $x11 $x2 negotiation_change  if typeofincident == 1,  dist(weibull) cluster(locationstart) 
eststo n4: streg $x11 $x2 pperson if typeofincident == 1,  dist(weibull) cluster(locationstart) 

estout *, cells(b(star fmt(%9.3f)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.01) stats(alpha N, fmt(2 2 0)) label collabels("") varlabels(_cons Constant) varwidth(25) modelwidth(10)
***********************
*********Table 4*******
***********************

** with non_kidnapping
global x1  num_hostages seq_release dnum_us_victim lnum_nonter_wound democracy 
global x11 num_hostages seq_release dnum_us_victim lnum_nonter_wound ppolity ppolity2 

global x2 number_entities lprisoners_demand  number_nationalities deadline_past1 

eststo clear
stset lduration_hours

eststo n1: streg $x1 $x2  if typeofincident != 1,  dist(weibull) cluster(locationstart) 
eststo n2: streg $x11 $x2 if typeofincident != 1,  dist(weibull) cluster(locationstart) 
eststo n3: streg $x11 $x2 pperson if typeofincident != 1,  dist(weibull) cluster(locationstart) 
eststo n4: streg $x11 $x2 $x5 if typeofincident != 1,  dist(weibull) cluster(locationstart) 

estout *, cells(b(star fmt(%9.3f)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.01) stats(alpha N, fmt(2 2 0)) label collabels("") varlabels(_cons Constant) varwidth(25) modelwidth(10)

*************************
*********Table 5&6*******
*************************
** Define variables
global x1   lnum_hostages seq_release lransom_demand  dnum_us_victim  democracy lnum_nonter_wound 
global x2 host_negotiation number_entities lprisoners_demand  number_nationalities deadline_past1 //

** Basic model
eststo clear

eststo n1: mlogit alter $x1 kidnap,  base(0) cluster(locationstart) 
eststo n2: mlogit alter $x1 $x2 skyjacking barricade non_aerial ,  base(0) cluster(locationstart)

estout *, cells(b(star fmt(%9.3f)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, fmt(2 2 0)) label collabels("") varwidth(25) modelwidth(10)

estout *, eform cells(b(star fmt(%9.3f)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N, fmt(2 2 0)) label collabels("") varwidth(25) modelwidth(10)

***********************
*********Table A1*******
***********************
eststo clear

stset lduration_hours

** Define variables
global x1   lnum_hostages seq_release lransom_demand  dnum_us_victim  democracy lnum_nonter_wound 
global x11  lnum_hostages seq_release lransom_demand  dnum_us_victim ppolity ppolity2  lnum_nonter_wound //
global x12  lnum_hostages seq_release lransom_demand  dnum_us_victim  democracy shoot_out
global x2 host_negotiation number_entities lprisoners_demand  number_nationalities deadline_past1 //
global x4 negotiation_change hpweapon pperson
global x5 negotiation_change pperson

** Basic model
eststo n1: streg $x1 kidnap,                                dist(weibull) frailty(gamma) shared(locationstart)  
eststo n2: streg $x11 $x2 skyjacking barricade non_aerial,  dist(weibull) frailty(gamma) shared(locationstart)
eststo n3: streg $x1 $x2 skyjacking barricade non_aerial,   dist(weibull) frailty(gamma) shared(locationstart)  
eststo n4: streg $x1 $x2 kidnap negotiation_change,         dist(weibull) frailty(gamma) shared(locationstart)  
eststo n5: streg $x1 $x2 kidnap pperson,                    dist(weibull) frailty(gamma) shared(locationstart) 
eststo n6: streg $x12 $x2 skyjacking barricade non_aerial,  dist(weibull) frailty(gamma) shared(locationstart) 

estout *, cells(b(star fmt(%9.3f)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N N_clust, fmt(2 2 0)) label collabels("") varlabels(_cons Constant) varwidth(25) modelwidth(10)
